@@ -237,6 +237,51 @@ query_if = function(data,
                     allow.cartesian = getOption("datatable.allow.cartesian"),   # default: FALSE
                     drop = NULL,
                     on = NULL){
+    UseMethod("query_if")
+}
+
+#' @rdname query_if
+#' @export
+query = function(data,
+                 j,
+                 by,
+                 keyby,
+                 with = TRUE,
+                 nomatch = getOption("datatable.nomatch"),
+                 mult = "all",
+                 roll = FALSE,
+                 rollends = if (roll=="nearest") c(TRUE,TRUE)
+                 else if (roll>=0) c(FALSE,TRUE)
+                 else c(TRUE,FALSE),
+                 which = FALSE,
+                 .SDcols,
+                 verbose = getOption("datatable.verbose"),                   # default: FALSE
+                 allow.cartesian = getOption("datatable.allow.cartesian"),   # default: FALSE
+                 drop = NULL,
+                 on = NULL){
+    UseMethod("query")
+}
+
+
+#' @export
+query_if.default = function(data,
+                    i,
+                    j,
+                    by,
+                    keyby,
+                    with = TRUE,
+                    nomatch = getOption("datatable.nomatch"),
+                    mult = "all",
+                    roll = FALSE,
+                    rollends = if (roll=="nearest") c(TRUE,TRUE)
+                    else if (roll>=0) c(FALSE,TRUE)
+                    else c(TRUE,FALSE),
+                    which = FALSE,
+                    .SDcols,
+                    verbose = getOption("datatable.verbose"),                   # default: FALSE
+                    allow.cartesian = getOption("datatable.allow.cartesian"),   # default: FALSE
+                    drop = NULL,
+                    on = NULL){
     is.data.frame(data) || stop("query/query_if: 'data' should be data.frame or data.table")
     call_expr = sys.call()
     if(!is.data.table(data)){
@@ -246,9 +291,9 @@ query_if = function(data,
     eval.parent(call_expr)
 }
 
-#' @rdname query_if
+
 #' @export
-query = function(data,
+query.default = function(data,
                  j,
                  by,
                  keyby,
@@ -272,5 +317,3 @@ query = function(data,
 }
 
 
-
-
